@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011, 2012, 2013, 2014, 2015.
+# Copyright (c) 2011 - 2018
 
 # Author(s):
 
@@ -39,36 +39,40 @@ TLE_URLS = ('http://celestrak.com/NORAD/elements/weather.txt',
             'https://www.celestrak.com/NORAD/elements/cubesat.txt',
             'http://celestrak.com/NORAD/elements/stations.txt',
             'https://www.celestrak.com/NORAD/elements/sarsat.txt',
-            'https://www.celestrak.com/NORAD/elements/noaa.txt')
+            'https://www.celestrak.com/NORAD/elements/noaa.txt',
+            'https://www.celestrak.com/NORAD/elements/amateur.txt')
 
 LOGGER = logging.getLogger(__name__)
+PKG_CONFIG_DIR = os.path.join(os.path.realpath(os.path.dirname(__file__)), 'etc')
 
 
 def read_platform_numbers(in_upper=False, num_as_int=False):
-    '''Read platform numbers from $PPP_CONFIG_DIR/platforms.txt if available.
-    '''
-
+    """Read platform numbers from $PPP_CONFIG_DIR/platforms.txt if available."""
     out_dict = {}
-    if "PPP_CONFIG_DIR" in os.environ:
-        platform_file = os.path.join(os.environ["PPP_CONFIG_DIR"],
-                                     "platforms.txt")
-        try:
-            fid = open(platform_file, 'r')
-        except IOError:
-            LOGGER.error("Platform file %s not found.", platform_file)
-            return out_dict
-        for row in fid:
-            # skip comment lines
-            if not row.startswith('#'):
-                parts = row.split()
-                if len(parts) < 2:
-                    continue
-                if in_upper:
-                    parts[0] = parts[0].upper()
-                if num_as_int:
-                    parts[1] = int(parts[1])
-                out_dict[parts[0]] = parts[1]
-        fid.close()
+    os.getenv('PPP_CONFIG_DIR', PKG_CONFIG_DIR)
+    platform_file = None
+    if 'PPP_CONFIG_DIR' in os.environ:
+        platform_file = os.path.join(os.environ['PPP_CONFIG_DIR'], 'platforms.txt')
+    if not platform_file or not os.path.isfile(platform_file):
+        platform_file = os.path.join(PKG_CONFIG_DIR, 'platforms.txt')
+
+    try:
+        fid = open(platform_file, 'r')
+    except IOError:
+        LOGGER.error("Platform file %s not found.", platform_file)
+        return out_dict
+    for row in fid:
+        # skip comment lines
+        if not row.startswith('#'):
+            parts = row.split()
+            if len(parts) < 2:
+                continue
+            if in_upper:
+                parts[0] = parts[0].upper()
+            if num_as_int:
+                parts[1] = int(parts[1])
+            out_dict[parts[0]] = parts[1]
+    fid.close()
 
     return out_dict
 
@@ -78,77 +82,23 @@ SATELLITES = read_platform_numbers(in_upper=True, num_as_int=False)
 The platform numbers are given in a file $PPP_CONFIG/platforms.txt
 in the following format:
 
-# Mappings between satellite catalogue numbers and corresponding
-# platform names from OSCAR.
-ALOS-2 39766
-CloudSat 29107
-CryoSat-2 36508
-CSK-1 31598
-CSK-2 32376
-CSK-3 33412
-CSK-4 37216
-DMSP-F15 25991
-DMSP-F16 28054
-DMSP-F17 29522
-DMSP-F18 35951
-DMSP-F19 39630
-EOS-Aqua 27424
-EOS-Aura 28376
-EOS-Terra 25994
-FY-2D 29640
-FY-2E 33463
-FY-2F 38049
-FY-2G 40367
-FY-3A 32958
-FY-3B 37214
-FY-3C 39260
-GOES-13 29155
-GOES-14 35491
-GOES-15 36411
-Himawari-6 28622
-Himawari-7 28937
-Himawari-8 40267
-INSAT-3A 27714
-INSAT-3C 27298
-INSAT-3D 39216
-JASON-2 33105
-Kalpana-1 27525
-Landsat-7 25682
-Landsat-8 39084
-Meteosat-7 24932
-Meteosat-8 27509
-Meteosat-9 28912
-Meteosat-10 38552
-Metop-A 29499
-Metop-B 38771
-NOAA-15 25338
-NOAA-16 26536
-NOAA-17 27453
-NOAA-18 28654
-NOAA-19 33591
-RadarSat-2 32382
-Sentinel-1A 39634
-SMOS 36036
-SPOT-5 27421
-SPOT-6 38755
-SPOT-7 40053
-Suomi-NPP 37849
-TanDEM-X 36605
-TerraSAR-X 31698
+.. literalinclude:: ../../etc/platforms.txt
+  :language: text
+  :lines: 4-
 '''
 
 
 def read(platform, tle_file=None, line1=None, line2=None):
-    """Read TLE for *satellite* from *tle_file*, from *line1* and *line2*, from
-   the newest file provided in the TLES pattern, or from internet if none is
-   provided.
-   """
+    """Read TLE for `platform` from `tle_file`
+
+    File is read from `line1` to `line2`, from the newest file provided in the
+    TLES pattern, or from internet if none is provided.
+    """
     return Tle(platform, tle_file=tle_file, line1=line1, line2=line2)
 
 
 def fetch(destination):
-    """fetch TLE from internet and save it to *destination*.
-   """
+    """Fetch TLE from internet and save it to `destination`."""
     with io.open(destination, mode="w", encoding="utf-8") as dest:
         for url in TLE_URLS:
             response = urlopen(url)
@@ -156,16 +106,12 @@ def fetch(destination):
 
 
 class ChecksumError(Exception):
-
-    '''ChecksumError.
-    '''
+    """ChecksumError."""
     pass
 
 
 class Tle(object):
-
-    """Class holding TLE objects.
-   """
+    """Class holding TLE objects."""
 
     def __init__(self, platform, tle_file=None, line1=None, line2=None):
         self._platform = platform.strip().upper()
@@ -200,22 +146,21 @@ class Tle(object):
 
     @property
     def line1(self):
-        '''Return first TLE line.'''
+        """Return first TLE line."""
         return self._line1
 
     @property
     def line2(self):
-        '''Return second TLE line.'''
+        """Return second TLE line."""
         return self._line2
 
     @property
     def platform(self):
-        '''Return satellite platform name.'''
+        """Return satellite platform name."""
         return self._platform
 
     def _checksum(self):
-        """Performs the checksum for the current TLE.
-        """
+        """Performs the checksum for the current TLE."""
         for line in [self._line1, self._line2]:
             check = 0
             for char in line[:-1]:
@@ -228,9 +173,7 @@ class Tle(object):
                 raise ChecksumError(self._platform + " " + line)
 
     def _read_tle(self):
-        '''Read TLE data.
-        '''
-
+        """Read TLE data."""
         if self._line1 is not None and self._line2 is not None:
             tle = self._line1.strip() + "\n" + self._line2.strip()
         else:
@@ -282,11 +225,10 @@ class Tle(object):
         self._line1, self._line2 = tle.split('\n')
 
     def _parse_tle(self):
-        '''Parse values from TLE data.
-        '''
+        """Parse values from TLE data."""
+
         def _read_tle_decimal(rep):
-            '''Convert *rep* to decimal value.
-            '''
+            """Convert *rep* to decimal value."""
             if rep[0] in ["-", " ", "+"]:
                 digits = rep[1:-2].strip()
                 val = rep[0] + "." + digits + "e" + rep[-2:]
@@ -338,10 +280,10 @@ class Tle(object):
 
 
 def main():
-    '''Main for testing TLE reading.
-    '''
+    """Main for testing TLE reading."""
     tle_data = read('Noaa-19')
     print(tle_data)
 
+
 if __name__ == '__main__':
     main()
